@@ -6,14 +6,17 @@ from typing import NamedTuple
 
 from PIL import ImageFont
 
+from dcspy import lcd_sdk
 from dcspy.log import config_logger
 
-__version__ = '1.1.1'
 SUPPORTED_CRAFTS = {'FA18Chornet': 'FA-18C_hornet', 'Ka50': 'Ka-50', 'F16C50': 'F-16C_50', 'F14B': 'F-14B'}
 SEND_ADDR = ('127.0.0.1', 7778)
 RECV_ADDR = ('', 5010)
 MULTICAST_IP = '239.255.50.10'
-LcdSize = NamedTuple('lcd_size', [('width', int), ('height', int)])
+LcdSize = NamedTuple('lcd_size', [('width', int), ('height', int), ('type', int)])
+LcdMono = LcdSize(width=lcd_sdk.MONO_WIDTH, height=lcd_sdk.MONO_HEIGHT, type=lcd_sdk.TYPE_MONO)
+LcdColor = LcdSize(width=lcd_sdk.COLOR_WIDTH, height=lcd_sdk.COLOR_HEIGHT, type=lcd_sdk.TYPE_COLOR)
+LCD_TYPES = {'G19': 'KeyboardColor', 'G510': 'KeyboardMono', 'G15 v1/v2': 'KeyboardMono', 'G13': 'KeyboardMono'}
 LOG = getLogger(__name__)
 config_logger(LOG)
 
@@ -21,10 +24,7 @@ LOG.debug(f'Arch: {name} / {platform} / {" / ".join(architecture())}')
 LOG.debug(f'Python: {python_implementation()}-{python_version()}')
 LOG.debug(f'{uname()}')
 
-
+font_name = 'DejaVuSansMono.ttf'
 if platform == 'win32':
-    FONT_11 = ImageFont.truetype('consola.ttf', 11)
-    FONT_16 = ImageFont.truetype('consola.ttf', 16)
-else:
-    FONT_11 = ImageFont.truetype('DejaVuSansMono.ttf', 11)
-    FONT_16 = ImageFont.truetype('DejaVuSansMono.ttf', 16)
+    font_name = 'consola.ttf'
+FONT = {size: ImageFont.truetype(font_name, size) for size in (11, 16, 22, 32)}
