@@ -1,38 +1,38 @@
+from functools import partial
 from logging import getLogger
 from string import whitespace
-from typing import Dict, Union
+from typing import Dict, Union, Tuple
 
 from PIL import Image, ImageDraw
 
-from dcspy import FONT_11, FONT_16
-from dcspy.sdk import lcd_sdk
+from dcspy import FONT, lcd_sdk, LcdSize
 
 try:
     from typing_extensions import TypedDict
 except ImportError:
     from typing import TypedDict
 
-
 BIOS_VALUE = TypedDict('BIOS_VALUE', {'class': str, 'args': Dict[str, int], 'value': Union[int, str]})
 LOG = getLogger(__name__)
 
 
 class Aircraft:
-    def __init__(self, width: int, height: int) -> None:
+    def __init__(self, lcd_type: LcdSize) -> None:
         """
         Basic constructor.
 
-        :param width: LCD width
-        :param height: LCD height
+        :param lcd_type: LCD type
         """
-        self.width = width
-        self.height = height
+        self.lcd = lcd_type
         self.bios_data: Dict[str, BIOS_VALUE] = {}
 
     def button_request(self, button: int, request: str = '\n') -> str:
         """
         Prepare aircraft specific DCS-BIOS request for button pressed.
 
+        For G13/G15/G510: 1-4
+        For G19 9-15: LEFT = 9, RIGHT = 10, OK = 11, CANCEL = 12, UP = 13, DOWN = 14, MENU = 15
+
         If button is out of scope new line is return.
 
         :param button: possible values 1-4
@@ -53,26 +53,32 @@ class Aircraft:
 
     def prepare_image(self) -> Image.Image:
         """
-        Prepare image to bo send to LCD.
+        Prepare image to be send to correct type of LCD.
 
         :return: image instance ready display on LCD
         :rtype: Image.Image
         """
-        raise NotImplementedError
+        img_for_lcd = {1: partial(Image.new, mode='1', size=(self.lcd.width, self.lcd.height), color=0),
+                       2: partial(Image.new, mode='RGBA', size=(self.lcd.width, self.lcd.height), color=(0, 0, 0, 0))}
+        try:
+            img = img_for_lcd[self.lcd.type]()
+            getattr(self, f'draw_for_lcd_type_{self.lcd.type}')(img)
+            # img.save(path.join(environ.get('TEMP', ''), f'{self.__class__.__name__}.png'), 'PNG')
+            return img
+        except KeyError as err:
+            LOG.debug(f'Wrong LCD type: {self.lcd} or key: {err}')
 
-    def set_bios(self, selector: str, value: str, update=True) -> None:
+    def set_bios(self, selector: str, value: str) -> None:
         """
         Set value for DCS-BIOS selector.
 
         :param selector:
         :param value:
-        :param update:
         """
         self.bios_data[selector]['value'] = value
         LOG.debug(f'{self.__class__.__name__} {selector} value: "{value}"')
         lcd_image = self.prepare_image()
-        if update:
-            self.update_display(lcd_image)
+        self.update_display(lcd_image)
 
     def get_bios(self, selector: str) -> Union[str, int]:
         """
@@ -85,16 +91,23 @@ class Aircraft:
         except KeyError:
             return ''
 
+    def draw_for_lcd_type_1(self, img: Image.Image) -> None:
+        """Prepare image for Aircraft for Mono LCD."""
+        raise NotImplementedError
+
+    def draw_for_lcd_type_2(self, img: Image.Image) -> None:
+        """Prepare image for Aircraft for Color LCD."""
+        raise NotImplementedError
+
 
 class FA18Chornet(Aircraft):
-    def __init__(self, width: int, height: int) -> None:
+    def __init__(self, lcd_type: LcdSize) -> None:
         """
         Basic constructor.
 
-        :param width: LCD width
-        :param height: LCD height
+        :param lcd_type: LCD type
         """
-        super().__init__(width, height)
+        super().__init__(lcd_type)
         self.bios_data: Dict[str, BIOS_VALUE] = {
             'ScratchpadStr1': {'class': 'StringBuffer', 'args': {'address': 0x744e, 'length': 2}, 'value': str()},
             'ScratchpadStr2': {'class': 'StringBuffer', 'args': {'address': 0x7450, 'length': 2}, 'value': str()},
@@ -111,55 +124,61 @@ class FA18Chornet(Aircraft):
             'OptionCueing3': {'class': 'StringBuffer', 'args': {'address': 0x742c, 'length': 1}, 'value': str()},
             'OptionCueing4': {'class': 'StringBuffer', 'args': {'address': 0x742e, 'length': 1}, 'value': str()},
             'OptionCueing5': {'class': 'StringBuffer', 'args': {'address': 0x7430, 'length': 1}, 'value': str()},
-            'FuelTotal': {'class': 'StringBuffer', 'args': {'address': 0x748a, 'length': 6}, 'value': str()}}
+            'IFEI_FUEL_DOWN': {'class': 'StringBuffer', 'args': {'address': 0x748a, 'length': 6}, 'value': str()},
+            'IFEI_FUEL_UP': {'class': 'StringBuffer', 'args': {'address': 0x7490, 'length': 6}, 'value': str()}}
 
-    def prepare_image(self) -> Image.Image:
-        """
-        Prepare image to bo send to LCD.
-
-        :return: image instance ready display on LCD
-        :rtype: Image.Image
-        """
-        img = Image.new('1', (self.width, self.height), 0)
-        draw = ImageDraw.Draw(img)
+    def _draw_common_data(self, draw: ImageDraw, fg: Union[int, Tuple[int, int, int, int]],
+                          bg: Union[int, Tuple[int, int, int, int]], scale: int) -> ImageDraw:
         # Scrachpad
-        draw.text((0, 0), f'{self.get_bios("ScratchpadStr1")}{self.get_bios("ScratchpadStr2")}{self.get_bios("ScratchpadNum")}', 1, FONT_16)
-        draw.line((0, 20, 115, 20), 1, 1)
-
+        draw.text(xy=(0, 0), fill=fg, font=FONT[16 * scale],
+                  text=f'{self.get_bios("ScratchpadStr1")}{self.get_bios("ScratchpadStr2")}{self.get_bios("ScratchpadNum")}')
+        draw.line(xy=(0, 20 * scale, 115 * scale, 20 * scale), fill=fg, width=1)
         # comm1
-        draw.rectangle((0, 29, 20, 42), 0, 1)
-        draw.text((2, 29), self.get_bios('COMM1'), 1, FONT_16)
-
+        draw.rectangle(xy=(0, 29 * scale, 20 * scale, 42 * scale), fill=bg, outline=fg)
+        draw.text(xy=(2 * scale, 29 * scale), text=self.get_bios('COMM1'), fill=fg, font=FONT[16 * scale])
         # comm2
-        offset_comm2 = 44
-        draw.rectangle((139 - offset_comm2, 29, 159 - offset_comm2, 42), 0, 1)
-        draw.text((140 - offset_comm2, 29), self.get_bios('COMM2'), 1, FONT_16)
-
+        offset_comm2 = 44 * scale
+        draw.rectangle(xy=(139 * scale - offset_comm2, 29 * scale, 159 * scale - offset_comm2, 42 * scale), fill=bg, outline=fg)
+        draw.text(xy=(140 * scale - offset_comm2, 29 * scale), text=self.get_bios('COMM2'), fill=fg, font=FONT[16 * scale])
         # option display 1..5 with cueing
         for i in range(1, 6):
-            offset = (i - 1) * 8
-            draw.text((120, offset), f'{i}{self.get_bios(f"OptionCueing{i}")}{self.get_bios(f"OptionDisplay{i}")}', 1, FONT_11)
-
+            offset = (i - 1) * 8 * scale
+            draw.text(xy=(120 * scale, offset), fill=fg, font=FONT[11 * scale],
+                      text=f'{i}{self.get_bios(f"OptionCueing{i}")}{self.get_bios(f"OptionDisplay{i}")}')
         # Fuel Totaliser
-        draw.text((36, 29), self.get_bios('FuelTotal'), 1, FONT_16)
-        return img
+        draw.text(xy=(36 * scale, 29 * scale), text=self.get_bios('IFEI_FUEL_UP'), fill=fg, font=FONT[16 * scale])
+        return draw
 
-    def set_bios(self, selector: str, value: str, update=True) -> None:
+    def draw_for_lcd_type_1(self, img: Image.Image) -> None:
+        """Prepare image for F/A-18C Hornet for Mono LCD."""
+        self._draw_common_data(draw=ImageDraw.Draw(img), fg=255, bg=0, scale=1)
+
+    def draw_for_lcd_type_2(self, img: Image.Image) -> None:
+        """Prepare image for F/A-18C Hornet for Color LCD."""
+        # todo: maybe add some public members, do some scaling and extract color to Logitech
+        green = (0, 255, 0, 255)
+        black = (0, 0, 0, 0)
+        draw = self._draw_common_data(draw=ImageDraw.Draw(img), fg=green, bg=black, scale=2)
+        draw.text(xy=(112, 58), text=self.get_bios('IFEI_FUEL_DOWN'), fill=green, font=FONT[32])
+
+    def set_bios(self, selector: str, value: str) -> None:
         """
         Set new data.
 
         :param selector:
         :param value:
-        :param update:
         """
         if selector in ('ScratchpadStr1', 'ScratchpadStr2', 'COMM1', 'COMM2'):
             value = value.replace('`', '1').replace('~', '2')
-        super().set_bios(selector, value, update)
+        super().set_bios(selector, value)
 
     def button_request(self, button: int, request: str = '\n') -> str:
         """
         Prepare F/A-18 Hornet specific DCS-BIOS request for button pressed.
 
+        For G13/G15/G510: 1-4
+        For G19 9-15: LEFT = 9, RIGHT = 10, OK = 11, CANCEL = 12, UP = 13, DOWN = 14, MENU = 15
+
         If button is out of scope new line is return.
 
         :param button: possible values 1-4
@@ -172,19 +191,24 @@ class FA18Chornet(Aircraft):
         action = {1: 'UFC_COMM1_CHANNEL_SELECT DEC\n',
                   2: 'UFC_COMM1_CHANNEL_SELECT INC\n',
                   3: 'UFC_COMM2_CHANNEL_SELECT DEC\n',
-                  4: 'UFC_COMM2_CHANNEL_SELECT INC\n'}
+                  4: 'UFC_COMM2_CHANNEL_SELECT INC\n',
+                  9: 'UFC_COMM1_CHANNEL_SELECT DEC\n',
+                  10: 'UFC_COMM1_CHANNEL_SELECT INC\n',
+                  14: 'UFC_COMM2_CHANNEL_SELECT DEC\n',
+                  13: 'UFC_COMM2_CHANNEL_SELECT INC\n',
+                  15: 'IFEI_DWN_BTN 1\nIFEI_DWN_BTN 0\n',
+                  12: 'IFEI_UP_BTN 1\nIFEI_UP_BTN 0\n'}
         return super().button_request(button, action.get(button, '\n'))
 
 
 class F16C50(Aircraft):
-    def __init__(self, width: int, height: int) -> None:
+    def __init__(self, lcd_type: LcdSize) -> None:
         """
         Basic constructor.
 
-        :param width: LCD width
-        :param height: LCD height
+        :param lcd_type: LCD type
         """
-        super().__init__(width, height)
+        super().__init__(lcd_type)
         self.bios_data: Dict[str, BIOS_VALUE] = {
             'DED_LINE_1': {'class': 'StringBuffer', 'args': {'address': 0x4502, 'length': 25}, 'value': str()},
             'DED_LINE_2': {'class': 'StringBuffer', 'args': {'address': 0x451c, 'length': 25}, 'value': str()},
@@ -192,32 +216,34 @@ class F16C50(Aircraft):
             'DED_LINE_4': {'class': 'StringBuffer', 'args': {'address': 0x4550, 'length': 25}, 'value': str()},
             'DED_LINE_5': {'class': 'StringBuffer', 'args': {'address': 0x456a, 'length': 25}, 'value': str()}}
 
-    def prepare_image(self) -> Image.Image:
-        """
-        Prepare image to bo send to LCD.
-
-        :return: image instance ready display on LCD
-        :rtype: Image.Image
-        """
-        img = Image.new('1', (self.width, self.height), 0)
+    def draw_for_lcd_type_1(self, img: Image.Image) -> None:
+        """Prepare image for F-16C Viper for Mono LCD."""
         draw = ImageDraw.Draw(img)
         for i in range(1, 6):
             offset = (i - 1) * 8
             # replace 'o' to degree sign and 'a' with up-down arrow
             text = str(self.get_bios(f'DED_LINE_{i}')).replace('o', '\u00b0').replace('a', '\u2195')
-            draw.text((0, offset), text, 1, FONT_11)
-        return img
+            draw.text(xy=(0, offset), text=text, fill=255, font=FONT[11])
+
+    def draw_for_lcd_type_2(self, img: Image.Image) -> None:
+        """Prepare image for F-16C Viper for Color LCD."""
+        draw = ImageDraw.Draw(img)
+        green = (0, 255, 0, 255)
+        for i in range(1, 6):
+            offset = (i - 1) * 16
+            # replace 'o' to degree sign and 'a' with up-down arrow
+            text = str(self.get_bios(f'DED_LINE_{i}')).replace('o', '\u00b0').replace('a', '\u2195')
+            draw.text(xy=(0, offset), text=text, fill=green, font=FONT[22])
 
 
 class Ka50(Aircraft):
-    def __init__(self, width: int, height: int) -> None:
+    def __init__(self, lcd_type: LcdSize) -> None:
         """
         Basic constructor.
 
-        :param width: LCD width
-        :param height: LCD height
+        :param lcd_type: LCD type
         """
-        super().__init__(width, height)
+        super().__init__(lcd_type)
         self.bios_data: Dict[str, BIOS_VALUE] = {
             'l1_apostr1': {'class': 'StringBuffer', 'args': {'address': 0x1934, 'length': 1}, 'value': str()},
             'l1_apostr2': {'class': 'StringBuffer', 'args': {'address': 0x1936, 'length': 1}, 'value': str()},
@@ -239,6 +265,9 @@ class Ka50(Aircraft):
         """
         Prepare Ka-50 Black Shark specific DCS-BIOS request for button pressed.
 
+        For G13/G15/G510: 1-4
+        For G19 9-15: LEFT = 9, RIGHT = 10, OK = 11, CANCEL = 12, UP = 13, DOWN = 14, MENU = 15
+
         If button is out of scope new line is return.
 
         :param button: possible values 1-4
@@ -251,37 +280,14 @@ class Ka50(Aircraft):
         action = {1: 'PVI_WAYPOINTS_BTN 1\nPVI_WAYPOINTS_BTN 0\n',
                   2: 'PVI_FIXPOINTS_BTN 1\nPVI_FIXPOINTS_BTN 0\n',
                   3: 'PVI_AIRFIELDS_BTN 1\nPVI_AIRFIELDS_BTN 0\n',
-                  4: 'PVI_TARGETS_BTN 1\nPVI_TARGETS_BTN 0\n'}
+                  4: 'PVI_TARGETS_BTN 1\nPVI_TARGETS_BTN 0\n',
+                  9: 'PVI_WAYPOINTS_BTN 1\nPVI_WAYPOINTS_BTN 0\n',
+                  10: 'PVI_FIXPOINTS_BTN 1\nPVI_FIXPOINTS_BTN 0\n',
+                  14: 'PVI_AIRFIELDS_BTN 1\nPVI_AIRFIELDS_BTN 0\n',
+                  13: 'PVI_TARGETS_BTN 1\nPVI_TARGETS_BTN 0\n'}
         return super().button_request(button, action.get(button, '\n'))
 
-    def prepare_image(self) -> Image.Image:
-        """
-        Prepare image to bo send to LCD.
-
-        :return: image instance ready display on LCD
-        :rtype: Image.Image
-        """
-        img = Image.new('1', (self.width, self.height), 0)
-        draw = ImageDraw.Draw(img)
-        text1, text2 = '', ''
-        draw.rectangle((0, 1, 85, 18), 0, 1)
-        draw.rectangle((0, 22, 85, 39), 0, 1)
-        draw.rectangle((88, 1, 103, 18), 0, 1)
-        draw.rectangle((88, 22, 103, 39), 0, 1)
-        l1_text = str(self.get_bios('l1_text'))
-        l2_text = str(self.get_bios('l2_text'))
-        if l1_text:
-            text1 = f'{l1_text[-6:-3]}{self.get_bios("l1_apostr1")}{l1_text[-3:-1]}{self.get_bios("l1_apostr2")}{l1_text[-1]}'
-        if l2_text:
-            text2 = f'{l2_text[-6:-3]}{self.get_bios("l2_apostr1")}{l2_text[-3:-1]}{self.get_bios("l2_apostr2")}{l2_text[-1]}'
-        line1 = f'{self.get_bios("l1_sign")}{text1} {self.get_bios("l1_point")}'
-        line2 = f'{self.get_bios("l2_sign")}{text2} {self.get_bios("l2_point")}'
-        draw.text((2, 3), line1, 1, FONT_16)
-        draw.text((2, 24), line2, 1, FONT_16)
-        self._auto_pilot_switch(draw)
-        return img
-
-    def _auto_pilot_switch(self, draw_obj: ImageDraw) -> None:
+    def _auto_pilot_switch_1(self, draw_obj: ImageDraw) -> None:
         """
         Draw rectangle and add text for autopilot channels in correct coordinates.
 
@@ -293,22 +299,83 @@ class Ka50(Aircraft):
                                                     ((111, 22, 124, 39), (114, 24), 'H', self.get_bios('AP_HDG_HOLD_LED')),
                                                     ((128, 22, 141, 39), (130, 24), 'A', self.get_bios('AP_ALT_HOLD_LED'))):
             if turn_on:
-                draw_obj.rectangle(c_rect, 1, 1)
-                draw_obj.text(c_text, ap_channel, 0, FONT_16)
+                draw_obj.rectangle(c_rect, fill=255, outline=255)
+                draw_obj.text(xy=c_text, text=ap_channel, fill=0, font=FONT[16])
             else:
-                draw_obj.rectangle(c_rect, 0, 1)
-                draw_obj.text(c_text, ap_channel, 1, FONT_16)
+                draw_obj.rectangle(xy=c_rect, fill=0, outline=255)
+                draw_obj.text(xy=c_text, text=ap_channel, fill=255, font=FONT[16])
+
+    def _auto_pilot_switch_2(self, draw_obj: ImageDraw) -> None:
+        """
+        Draw rectangle and add text for autopilot channels in correct coordinates.
+
+        :param draw_obj: ImageDraw object form PIL
+        """
+        green = (0, 255, 0, 255)
+        black = (0, 0, 0, 0)
+        for c_rect, c_text, ap_channel, turn_on in (((222, 2, 248, 36), (228, 6), 'B', self.get_bios('AP_BANK_HOLD_LED')),
+                                                    ((256, 2, 282, 36), (260, 6), 'P', self.get_bios('AP_PITCH_HOLD_LED')),
+                                                    ((290, 2, 316, 36), (294, 6), 'F', self.get_bios('AP_FD_LED')),
+                                                    ((222, 44, 248, 78), (228, 48), 'H', self.get_bios('AP_HDG_HOLD_LED')),
+                                                    ((256, 44, 282, 78), (260, 48), 'A', self.get_bios('AP_ALT_HOLD_LED'))):
+            if turn_on:
+                draw_obj.rectangle(c_rect, fill=green, outline=green)
+                draw_obj.text(xy=c_text, text=ap_channel, fill=black, font=FONT[32])
+            else:
+                draw_obj.rectangle(xy=c_rect, fill=black, outline=green)
+                draw_obj.text(xy=c_text, text=ap_channel, fill=green, font=FONT[32])
+
+    def draw_for_lcd_type_1(self, img: Image.Image) -> None:
+        """Prepare image for Ka-50 Black Shark for Mono LCD."""
+        draw = ImageDraw.Draw(img)
+        text1, text2 = '', ''
+        draw.rectangle(xy=(0, 1, 85, 18), fill=0, outline=255)
+        draw.rectangle(xy=(0, 22, 85, 39), fill=0, outline=255)
+        draw.rectangle(xy=(88, 1, 103, 18), fill=0, outline=255)
+        draw.rectangle(xy=(88, 22, 103, 39), fill=0, outline=255)
+        l1_text = str(self.get_bios('l1_text'))
+        l2_text = str(self.get_bios('l2_text'))
+        if l1_text:
+            text1 = f'{l1_text[-6:-3]}{self.get_bios("l1_apostr1")}{l1_text[-3:-1]}{self.get_bios("l1_apostr2")}{l1_text[-1]}'
+        if l2_text:
+            text2 = f'{l2_text[-6:-3]}{self.get_bios("l2_apostr1")}{l2_text[-3:-1]}{self.get_bios("l2_apostr2")}{l2_text[-1]}'
+        line1 = f'{self.get_bios("l1_sign")}{text1} {self.get_bios("l1_point")}'
+        line2 = f'{self.get_bios("l2_sign")}{text2} {self.get_bios("l2_point")}'
+        draw.text(xy=(2, 3), text=line1, fill=255, font=FONT[16])
+        draw.text(xy=(2, 24), text=line2, fill=255, font=FONT[16])
+        self._auto_pilot_switch_1(draw)
+
+    def draw_for_lcd_type_2(self, img: Image.Image) -> None:
+        """Prepare image for Ka-50 Black Shark for Mono LCD."""
+        draw = ImageDraw.Draw(img)
+        green = (0, 255, 0, 255)
+        black = (0, 0, 0, 0)
+        text1, text2 = '', ''
+        draw.rectangle(xy=(0, 2, 170, 36), fill=black, outline=green)
+        draw.rectangle(xy=(0, 44, 170, 78), fill=black, outline=green)
+        draw.rectangle(xy=(176, 2, 206, 36), fill=black, outline=green)
+        draw.rectangle(xy=(176, 44, 203, 78), fill=black, outline=green)
+        l1_text = str(self.get_bios('l1_text'))
+        l2_text = str(self.get_bios('l2_text'))
+        if l1_text:
+            text1 = f'{l1_text[-6:-3]}{self.get_bios("l1_apostr1")}{l1_text[-3:-1]}{self.get_bios("l1_apostr2")}{l1_text[-1]}'
+        if l2_text:
+            text2 = f'{l2_text[-6:-3]}{self.get_bios("l2_apostr1")}{l2_text[-3:-1]}{self.get_bios("l2_apostr2")}{l2_text[-1]}'
+        line1 = f'{self.get_bios("l1_sign")}{text1} {self.get_bios("l1_point")}'
+        line2 = f'{self.get_bios("l2_sign")}{text2} {self.get_bios("l2_point")}'
+        draw.text(xy=(4, 6), text=line1, fill=green, font=FONT[32])
+        draw.text(xy=(4, 48), text=line2, fill=green, font=FONT[32])
+        self._auto_pilot_switch_2(draw)
 
 
 class F14B(Aircraft):
-    def __init__(self, width: int, height: int) -> None:
+    def __init__(self, lcd_type: LcdSize) -> None:
         """
         Basic constructor.
 
-        :param width: LCD width
-        :param height: LCD height
+        :param lcd_type: LCD type
         """
-        super().__init__(width, height)
+        super().__init__(lcd_type)
         self.bios_data: Dict[str, BIOS_VALUE] = {
             'RIO_CAP_CLEAR': {'class': 'IntegerBuffer', 'args': {'address': 0x12d4, 'mask': 0x1, 'shift_by': 0x0}, 'value': int()},
             'RIO_CAP_SW': {'class': 'IntegerBuffer', 'args': {'address': 0x12d2, 'mask': 0x8000, 'shift_by': 0xf}, 'value': int()},
@@ -319,6 +386,9 @@ class F14B(Aircraft):
         """
         Prepare F-14 Tomcat specific DCS-BIOS request for button pressed.
 
+        For G13/G15/G510: 1-4
+        For G19 9-15: LEFT = 9, RIGHT = 10, OK = 11, CANCEL = 12, UP = 13, DOWN = 14, MENU = 15
+
         If button is out of scope new line is return.
 
         :param button: possible values 1-4
@@ -331,17 +401,20 @@ class F14B(Aircraft):
         action = {1: 'RIO_CAP_CLEAR 1\nRIO_CAP_CLEAR 0\n',
                   2: 'RIO_CAP_SW 1\nRIO_CAP_SW 0\n',
                   3: 'RIO_CAP_NE 1\nRIO_CAP_NE 0\n',
-                  4: 'RIO_CAP_ENTER 1\nRIO_CAP_ENTER 0\n'}
+                  4: 'RIO_CAP_ENTER 1\nRIO_CAP_ENTER 0\n',
+                  9: 'RIO_CAP_CLEAR 1\nRIO_CAP_CLEAR 0\n',
+                  10: 'RIO_CAP_SW 1\nRIO_CAP_SW 0\n',
+                  14: 'RIO_CAP_NE 1\nRIO_CAP_NE 0\n',
+                  13: 'RIO_CAP_ENTER 1\nRIO_CAP_ENTER 0\n'}
         return super().button_request(button, action.get(button, '\n'))
 
-    def prepare_image(self) -> Image.Image:
-        """
-        Prepare image to bo send to LCD.
-
-        :return: image instance ready display on LCD
-        :rtype: Image.Image
-        """
-        img = Image.new('1', (self.width, self.height), 0)
+    def draw_for_lcd_type_1(self, img: Image.Image) -> None:
+        """Prepare image for F-14B Tomcat for Mono LCD."""
         draw = ImageDraw.Draw(img)
-        draw.text((2, 3), 'F-14B Tomcat', 1, FONT_16)
-        return img
+        draw.text(xy=(2, 3), text='F-14B Tomcat', fill=255, font=FONT[16])
+
+    def draw_for_lcd_type_2(self, img: Image.Image) -> None:
+        """Prepare image for F-14B Tomcat for Color LCD."""
+        draw = ImageDraw.Draw(img)
+        green = (0, 255, 0, 255)
+        draw.text(xy=(2, 3), text='F-14B Tomcat', fill=green, font=FONT[32])
